==> zendesk_classic-1.0.1.tar.gz: android/src/main/java/com/avinashgotluru/zendesk_classic/ZendeskClassicPlugin.java <==
package com.avinashgotluru.zendesk_classic;

import android.app.Activity;
import android.content.Context;
import androidx.annotation.NonNull;
import androidx.appcompat.app.AppCompatActivity;
import io.flutter.embedding.engine.plugins.FlutterPlugin;
import io.flutter.embedding.engine.plugins.activity.ActivityAware;
import io.flutter.embedding.engine.plugins.activity.ActivityPluginBinding;
import io.flutter.plugin.common.MethodCall;
import io.flutter.plugin.common.MethodChannel;
import io.flutter.plugin.common.MethodChannel.MethodCallHandler;
import io.flutter.plugin.common.MethodChannel.Result;
import zendesk.chat.ChatConfiguration;
import zendesk.chat.ChatEngine;
import zendesk.classic.messaging.MessagingActivity;
import zendesk.classic.messaging.MessagingConfiguration;

/**
 * ZendeskClassicPlugin
 */
public class ZendeskClassicPlugin extends AppCompatActivity implements FlutterPlugin, MethodCallHandler, ActivityAware {
    /// The MethodChannel that will the communication between Flutter and native Android
    ///
    /// This local reference serves to register the plugin with the Flutter Engine and unregister it
    /// when the Flutter Engine is detached from the Activity
    private MethodChannel channel;
    private Context context;
    private Activity activity;

    @Override
    public void onAttachedToEngine(@NonNull FlutterPluginBinding flutterPluginBinding) {
        channel = new MethodChannel(flutterPluginBinding.getBinaryMessenger(), "zendesk_classic");
        channel.setMethodCallHandler(this);
        context = flutterPluginBinding.getApplicationContext();
    }

    @Override
    public void onMethodCall(@NonNull MethodCall call, @NonNull Result result) {
        ZendeskService zendeskService = new ZendeskService();
        switch (call.method) {
            case "getPlatformVersion":
                result.success("Android " + android.os.Build.VERSION.RELEASE);
                break;
            case "zendesk":

                String zendeskUrl = call.argument("zendeskUrl");
                String appId = call.argument("appId");
                String oauthClientId = call.argument("oauthClientId");

                zendeskService.initZendesk(context, zendeskUrl, appId, oauthClientId);

                break;
            case "support":

                zendeskService.initZendeskSupport();

                break;
            case "bot":

                zendeskService.initZendeskBot();

                break;
            case "chat":

                String chatAccountKey = call.argument("chatAccountKey");
                String botName = call.argument("botName");
                zendeskService.initZendeskChat(context, chatAccountKey);
                ChatConfiguration chatConfiguration = ChatConfiguration.builder().build();

                MessagingConfiguration.Builder messageBuilder = MessagingActivity.builder();

                if (botName != null && !botName.isEmpty()) {
                    messageBuilder.withEngines(ChatEngine.engine());
                    messageBuilder.withBotLabelString(botName);
                    messageBuilder.withMultilineResponseOptionsEnabled(true);
                } else {
                    messageBuilder.withEngines(ChatEngine.engine());
                    messageBuilder.withMultilineResponseOptionsEnabled(true);
                }
                messageBuilder.show(context, chatConfiguration);
                break;
            default:
                result.notImplemented();
                break;
        }
    }

    @Override
    public void onDetachedFromEngine(@NonNull FlutterPluginBinding binding) {
        channel.setMethodCallHandler(null);
    }

    @Override
    public void onAttachedToActivity(@NonNull ActivityPluginBinding binding) {
        this.activity = binding.getActivity();
    }

    @Override
    public void onDetachedFromActivityForConfigChanges() {
        this.activity = null;
    }

    @Override
    public void onReattachedToActivityForConfigChanges(@NonNull ActivityPluginBinding binding) {
        this.activity = binding.getActivity();
    }

    @Override
    public void onDetachedFromActivity() {
        this.activity = null;
    }
}

==> zendesk_classic-1.0.2.tar.gz: android/src/main/java/com/avinashgotluru/zendesk_classic/ZendeskClassicPlugin.java <==
package com.avinashgotluru.zendesk_classic;

import android.app.Activity;
import android.content.Context;
import androidx.annotation.NonNull;
import androidx.appcompat.app.AppCompatActivity;
import io.flutter.embedding.engine.plugins.FlutterPlugin;
import io.flutter.embedding.engine.plugins.activity.ActivityAware;
import io.flutter.embedding.engine.plugins.activity.ActivityPluginBinding;
import io.flutter.plugin.common.MethodCall;
import io.flutter.plugin.common.MethodChannel;
import io.flutter.plugin.common.MethodChannel.MethodCallHandler;
import io.flutter.plugin.common.MethodChannel.Result;
import zendesk.chat.ChatConfiguration;
import zendesk.chat.ChatEngine;
import zendesk.classic.messaging.MessagingActivity;
import zendesk.classic.messaging.MessagingConfiguration;

/**
 * ZendeskClassicPlugin
 */
public class ZendeskClassicPlugin extends AppCompatActivity implements FlutterPlugin, MethodCallHandler, ActivityAware {
    /// The MethodChannel that will the communication between Flutter and native Android
    ///
    /// This local reference serves to register the plugin with the Flutter Engine and unregister it
    /// when the Flutter Engine is detached from the Activity
    private MethodChannel channel;
    private Context context;
    private Activity activity;

    @Override
    public void onAttachedToEngine(@NonNull FlutterPluginBinding flutterPluginBinding) {
        channel = new MethodChannel(flutterPluginBinding.getBinaryMessenger(), "zendesk_classic");
        channel.setMethodCallHandler(this);
        context = flutterPluginBinding.getApplicationContext();
    }

    @Override
    public void onMethodCall(@NonNull MethodCall call, @NonNull Result result) {
        ZendeskService zendeskService = new ZendeskService();
        switch (call.method) {
            case "getPlatformVersion":
                result.success("Android " + android.os.Build.VERSION.RELEASE);
                break;
            case "zendesk":

                String zendeskUrl = call.argument("zendeskUrl");
                String appId = call.argument("appId");
                String oauthClientId = call.argument("oauthClientId");

                zendeskService.initZendesk(context, zendeskUrl, appId, oauthClientId);

                break;
            case "support":

                zendeskService.initZendeskSupport();

                break;
            case "bot":

                zendeskService.initZendeskBot();

                break;
            case "chat":

                String chatAccountKey = call.argument("chatAccountKey");
                String botName = call.argument("botName");
                zendeskService.initZendeskChat(context, chatAccountKey);
                ChatConfiguration chatConfiguration = ChatConfiguration.builder().build();

                MessagingConfiguration.Builder messageBuilder = MessagingActivity.builder();

                if (botName != null && !botName.isEmpty()) {
                    messageBuilder.withEngines(ChatEngine.engine());
                    messageBuilder.withBotLabelString(botName);
                    messageBuilder.withMultilineResponseOptionsEnabled(true);
                } else {
                    messageBuilder.withEngines(ChatEngine.engine());
                    messageBuilder.withMultilineResponseOptionsEnabled(true);
                }
                messageBuilder.show(this.activity, chatConfiguration);
                break;
            default:
                result.notImplemented();
                break;
        }
    }

    @Override
    public void onDetachedFromEngine(@NonNull FlutterPluginBinding binding) {
        channel.setMethodCallHandler(null);
    }

    @Override
    public void onAttachedToActivity(@NonNull ActivityPluginBinding binding) {
        this.activity = binding.getActivity();
    }

    @Override
    public void onDetachedFromActivityForConfigChanges() {
        this.activity = null;
    }

    @Override
    public void onReattachedToActivityForConfigChanges(@NonNull ActivityPluginBinding binding) {
        this.activity = binding.getActivity();
    }

    @Override
    public void onDetachedFromActivity() {
        this.activity = null;
    }
}
